History
=======

This package came out of the `Dask Distributed`_ project with help from the
Pangeo_ collaboration. The original code was contained in the ``distributed.cli.dask_mpi``
module and the original tests were contained in the ``distributed.cli.tests.test_dask_mpi``
module.  The impetus for pulling Dask-MPI out of Dask-Distributed was provided by feedback
on the Dask Distributted `Issue 2402 <https://github.com/dask/distributed/issues/2402>`_.

Development history for these original files was preserved.

.. _`Dask Distributed`: https://github.com/dask/distributed
.. _Pangeo: https://pangeo.io
